-- Data for existing plugins we may want to handle in specific ways

import "Equendil.PluginMng.Command";

KnownPlugins = {};

-- List of plugins that should be excluded from the auto list, and to keep hidden unless we show all
KnownPlugins.ExcludedPlugins = {
	"Bootstrap", 
	"BootstrapReloader", 
	"CombatAnalysisLoader", 
	"MoorMapTerminator", 
	"MoorMapDefaults", 
	"MoorMapLoader", 
	"BigPack",
	"HugeBagUtility",
	"SortPackButton",
	"SortPackReload",
};

-- Command templates for specific plugins
KnownPlugins.CommandTemplates = {
	Ah = nil, -- no GUI or useful command without parameters
	AltInventory = { name = "Alt Inventory", command = "/altinventory toggle", mode = Command.Mode.LoadOrRun },
	AltTracker = { name = "Alt Tracker", command = "/at", mode = Command.Mode.LoadOrRun },
	Aura = nil, -- does not seem to have a command
	BevyOBars2 = nil, -- options etc from menu on the bars, no global settings window
	BigPackWrapper = nil, -- bag plugin, opens through the inventory icons / key binds
	BusyBee = { name = "Busy Bee Tasks", command = "/bzb toggle", mode = Command.Mode.LoadOrRun },
	Bootstrap = { name = "Reload Bootstrap", command = "/bootstrap reload", mode = Command.Mode.RunOnly },
	BuffBars = { name = "BuffBars", command = "/buffbars options", mode = Command.Mode.LoadOrRun }, 
	BuffHelper = nil, -- doesn't seem to have commands - german plugin
	BuffMonitor = { name = "Buff Monitor", command = "/bm toggle", mode = Command.Mode.LoadOrRun },
	Calculator = nil, -- plugin has no command
	Calendar = { name = "Calendar", command = "/calendar show", mode = Command.Mode.LoadOrRun },
	CampSite = { name = "CampSite", command = "/csw", mode = Command.Mode.LoadAndRun },
	ChatEdit = nil, -- bag plugin
	CJHelper = nil, -- seemingly no command for this
	CJTome = nil, -- no command for this plugin, uses an icon
	CombatAnalysis = { name = "Combat Analysis", command = "/ca show", mode = Command.Mode.LoadOrRun },
	Compendium = nil, -- no command for this plugin, uses an icon. Note: Resides in its own environment
	Crafters = { name = "Crafters", command = "/craft", mode = Command.Mode.LoadOrRun },
	CTime = { name = "CTime", command = "/CTime toogle", mode = Command.Mode.LoadOrRun },
	DailyTasks = { name = "Daily Tasks", command = "/dtw", mode = Command.Mode.LoadOrRun }, -- DailyTasks registers the 'dtw command 
	Emo = nil,
	ExtraSlots = { name = "ExtraSlots", command = "/extraslots setup", mode = Command.Mode.LoadOrRun },
	FilterBag = nil, -- no command, GUI from regular inventory icons / keybinds
	HereBeDragons = { name = "Here Be Dragons", command = "/hbd", mode = Command.Mode.LoadOrRun },
	Horsey = nil, -- no command, uses an icon
	Horsey2 = nil, -- no command, uses an icon
	Horsey3 = nil, -- no command, uses an icon
	HunterFocus = nil, -- no command, perma GUI I guess, untested
	HugeBag = nil, --bag plugin, shouldn't need the menu
	IOF = {name = "IOF", command = "/iof toggle", mode = Command.Mode.LoadOrRun },
	IRV = { name = "IRV", command = "/irv show", mode = Command.Mode.LoadOrRun },
	KragenBars = { name = "Kragen Bars", command = "/kragenbars setup", mode = Command.Mode.LoadOrRun },
	KragenSlots = { name = "Kragen Slots", command = "/kragenslots setup", mode = Command.Mode.LoadOrRun }, 
	LIP = { name = "LIP", command = "/lip", mode = Command.Mode.LoadAndRun },
	Lotropad = { name = "Lotropad", command = "/lotropad", mode = Command.Mode.LoadOrRun },
	LowWarn = nil, -- seemingly no command
	Lyrical = { name = "Lyrical", command = "/lyrical toggle", mode = Command.Mode.LoadOrRun },
	mgabc = { name = "MG abc Player", command = "/mgabc toggle", mode = Command.Mode.LoadOrRun },
	MoorMap = { name = "MoorMap", command = "/moormap toggle", mode = Command.Mode.LoadOrRun },
	MouseCursorHA = { name = "MouseCursorHA", command = "/mcha", mode = Command.Mode.LoadOrRun };
	MouseCircle = nil, -- no GUI
	Noggin = nil, --add on for palantir, shouldn't end up in the menu
	OneBigBag = nil, -- bag plugin, doesn't need the menu
	PagedSlots = { name = "PagedSlots", command = "/slots toggle", mode = Command.Mode.LoadOrRun },
	Palantir = { name = "Palantir", command = "/palantir options", mode = Command.Mode.LoadOrRun },
	PetCarousel = nil, -- no commands
	Pi = nil, -- shouldn't be in the menu, needs parameters
	PopUps = nil, -- no commands
	PotHelper = { name = "PvP Pot Helper", command = "/ph", mode = Command.Mode.LoadOrRun },
	PredictInGameTime = { name = "PredictInGameTime", command = "/pigt", mode = Command.Mode.LoadOrRun }, 
	QuickLoad = nil, -- plugin loader, shouldn't end up in the menu ...
	Rainbow = { name = "RainbowChat", command = "/rainbow setup", mode = Command.Mode.LoadOrRun },
	RepRef = { name = "Reputation Reference", command = "/rrw", mode = Command.Mode.LoadOrRun },
	Satchel = nil, -- bag plugin
	["Simply Notes"] = { name = "Simply Notes", command = "/notes", mode = Command.Mode.LoadOrRun }, 
	Songbook = { name = "Songbook", command = "/songbook show", mode = Command.Mode.LoadOrRun },
	SortPack = nil, -- bag plugin,
	SuttQuickslots = nil, 
	Tobii = nil, -- bag plugin
	TonicBars = { name = "TonicBars", command = "/tb", mode = Command.Mode.LoadOrRun },
	Travel = { name = "Travel ", command = "/travel toggle", mode = Command.Mode.LoadOrRun },
	TravelRef = { name = "TravelRef", command = "/trw", mode = Command.Mode.LoadOrRun },
	VBar = nil, -- perma GUI
	VitalBars = nil, -- no commands ?
	WardenEase = nil, -- no command 
	WardenIndicator = { name = "Warden Indicator", command = "/wi option", mode = Command.Mode.LoadOrRun },
	WardenTrainerLite = nil, -- no command ?
};

KnownPlugins.Icons = {
	Ah = nil, -- no GUI, shouldn't end up in the menu
	AltInventory = "GaranStuff/AltInventory/Resources/bags_up.jpg",
	AltTracker = 0x4101DDEF, -- icon with many character faces on it
	Aura = 0x41019E43, -- arbitrary fear eye debuff,
	BevyOBars2 = 0x41102B6B, -- arbitrary "slot" background, glowing
	BigPackWrapper = 0x41101B7D, -- arbitrary bag icon
	BusyBee = 0x41005FC1, -- deed panel menu icon
	Bootstrap = "Equendil/UI/images/onoff.tga",	
	BuffBars = 0x41019E43, -- arbitrary fear eye debuff,
	BuffHelper = 0x41019E43, -- arbitrary fear eye debuff,
	BuffMonitor = 0x41019E43, -- arbitrary fear eye debuff,
	Calculator = 0x41000267, -- "+" icon
	Calendar = "FrostyPlugins/Calendar/Resources/CalendarPluginIcon.tga",
	CampSite = 0x410D4638, -- camp site icon
	ChatEdit = "GaluhadPlugins/ChatEdit/resources/Open.jpg", 
	CJHelper = 0x41007EDE, -- CJ skill-picker icon
	CJTome = 0x41007EDE, -- CJ skill-picker icon
	CombatAnalysis = 0x41005FC9, -- in combat status picture
	Compendium = "Compendium/common/resources/images/icon.tga",
	Crafters = 0x4101DDEF, -- icon with many character faces on it
	CTime = "ChronPlugins/CTime/Resources/Uhr1.tga",
	DailyTasks = 0x41005FC1, -- deed panel menu icon
	Emo = nil, 
	ExtraSlots = 0x41102B6B, -- arbitrary "slot" background, glowing
	FilterBag = 0x41101B7D, -- arbitrary bag icon
	HereBeDragons = 0x41103547, -- sauron's eye
	Horsey = "rushl/Horsey/Resources/HorseyIcon2.tga",
	Horsey2 = "rushl/Horsey2/Resources/Horsey2Icon.tga",
	Horsey3 = "rushl/Horsey3/Resources/Horsey3Icon.tga",
	HunterFocus = 0x410095C2, -- Hunter class icon
	HugeBag = 0x41101B7D, -- arbitrary bag icon
	IOF = 0x411016B0, -- instance join icon
	IRV = 0x41103547, -- sauron's eye
	KragenBars = "KragenPlugs/KragenBars/Resources/Minstrel.tga", -- picked that one a bit arbitrarily
	KragenSlots = "KragenPlugs/KragenSlots/Resources/icon.tga",
	LIP = 0x410EE417, -- legendary item panel icon
	Lotropad = "Chiran/Lotropad/toggle.tga",
	LowWarn = 0x410FBAAA, -- morale pot
	Lyrical = 0x4101F7DE, -- lute icon
	mgabc = 0x4101F7DE, -- lute icon
	MoorMap = "GaranStuff/MoorMap/Resources/map_up.jpg",
	MouseCursorHA = 0x41008257, -- cursor icon
	MouseCircle = "moebius92/MouseCircle/circle.tga",
	Noggin = nil, -- apparently an add on for palantir, shouldn't end up in the menu
	OneBigBag = 0x41101B7D, -- arbitrary bag icon
	PagedSlots = 0x41102B6B, -- arbitrary "slot" background, glowing
	Palantir = 0x410FBAAA, -- morale pot icon
	PetCarousel = 0x4110CA40, -- raven icon
	Pi = 0x410E8297, -- coin icon
	PopUps = "JackdawPlugins/PopUps/Resources/Star.tga",
	PotHelper = 0x41001BBA, -- fear pot
	PredictInGameTime = nil,
	QuickLoad = nil, -- plugin loader, shouldn't be in the menu
	Rainbow = "GaranStuff/Rainbow/Resources/icon_up.jpg",
	RepRef = 0x41101A6E, -- reputation panel icon
	Satchel = 0x41101B7D, -- arbitrary bag icon
	["Simply Notes"] = 0x410F4D89, -- book icon
	Songbook = "Chiran/Songbook/toggle.tga",
	SortPack = 0x41101B7D, -- arbitrary bag icon
	SuttQuickslots = 0x41102B6B, -- arbitrary "slot" background, glowing
	Tobii = 0x41101B7D, -- arbitrary bag icon
	TonicBars = "Tonic/TonicBars/Resources/TonicGoblet.tga",
	Travel = "DhorPlugins/Travel/Resources/travel.tga",
	TravelRef = 0x4100885D, -- bree travel icon
	VBar = 0x411044A6, -- green progress bar
	VitalBars = "Faflaf/VitalBars/Resources/Ring.tga",
	WardenEase = 0x41108673, -- warden class icon
	WardenIndicator = 0x41108673, -- warden class icon
	WardenTrainerLite = 0x41108673, -- warden class icon
};